# python-pg-cnab240

A CNAB 240 Package to proccess Bank payment shipping files and return files.

### Installation

    pip install pg_cnab240

### Implemented Banks

 - [X] Itau Unibanco
 - [ ] Banco de Brasil
 - [ ] Bradesco
 - [ ] Santander
